**********
References
**********

.. _glossary:

Glossary
--------

.. glossary::

    GMM
      Gaussian Mixture Model. A statistical model that assumes that the data is generated by
      a mixture of several Gaussian distributions.

    Exposure
      Quantity to convert the number of photons into a physical flux, such as TeV/s/cm^2.
      Typically represented by product of the effective area of the instrument and the exposure
      time of the observation.

    IACT
      Imaging Atmospheric Cherenkov Telescope. A telescope that detects Cherenkov light from
      air showers induced by gamma rays in the atmosphere. Examples are H.E.S.S., MAGIC, VERITAS
      and CTA.

    Jolideco
      Jolideco stands for (Jo)int (Li)kelihood (Deco)nvolution

    PSF
      Point Spread Function of an instrument.

    Patch Prior
      A prior distribution, that relies on the statistical properties of image patches.


Bibliography
------------

This is the bibliography containing the literature references for the implemented methods
referenced from the Jolideco docs.

.. bibliography::
